Replace

Struct Replace 

pub struct Replace<A, B, C> {
    pub source: A,
    pub needle: B,
    pub replacement: C,
}
A Writeable adapter that replaces occurrences of a needle with a replacement.

This adapter performs the replacement in a streaming fashion during write_to, requiring zero allocations.

Examples

use writeable::adapters::Replace;
use writeable::assert_writeable_eq;
use writeable::concat_writeable;

let source = concat_writeable!("I 💖 🦀", " and 🦀 loves me!");
let replace = Replace {
    source,
    needle: "🦀",
    replacement: "Rust",
};

assert_writeable_eq!(replace, "I 💖 Rust and Rust loves me!");

Fields

source: A

The source writeable.

needle: B

The needle to search for.

replacement: C

The replacement writeable.

Implementations

Source

impl<'a, A: Writeable, C: Writeable> Replace<A, &'a str, C>

pub fn to_string(&self) -> String

Converts the given value to a String.

Under the hood, this uses an efficient Writeable implementation.

If you don’t need an allocated String, but e.g. need to write this to some sink, it is more efficient to use Writeable directly.